==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1PodSecurityPolicySpecBuilder.java <==
package io.kubernetes.client.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ExtensionsV1beta1PodSecurityPolicySpecBuilder extends ExtensionsV1beta1PodSecurityPolicySpecFluentImpl<ExtensionsV1beta1PodSecurityPolicySpecBuilder> implements VisitableBuilder<ExtensionsV1beta1PodSecurityPolicySpec,ExtensionsV1beta1PodSecurityPolicySpecBuilder>{

    ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent;
    Boolean validationEnabled;

    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(){
            this(true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(Boolean validationEnabled){
            this(new ExtensionsV1beta1PodSecurityPolicySpec(), validationEnabled);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent){
            this(fluent, true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ExtensionsV1beta1PodSecurityPolicySpec(), validationEnabled);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent,ExtensionsV1beta1PodSecurityPolicySpec instance){
            this(fluent, instance, true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent,ExtensionsV1beta1PodSecurityPolicySpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAllowPrivilegeEscalation(instance.isAllowPrivilegeEscalation());

            fluent.withAllowedCapabilities(instance.getAllowedCapabilities());

            fluent.withAllowedFlexVolumes(instance.getAllowedFlexVolumes());

            fluent.withAllowedHostPaths(instance.getAllowedHostPaths());

            fluent.withAllowedUnsafeSysctls(instance.getAllowedUnsafeSysctls());

            fluent.withDefaultAddCapabilities(instance.getDefaultAddCapabilities());

            fluent.withDefaultAllowPrivilegeEscalation(instance.isDefaultAllowPrivilegeEscalation());

            fluent.withForbiddenSysctls(instance.getForbiddenSysctls());

            fluent.withFsGroup(instance.getFsGroup());

            fluent.withHostIPC(instance.isHostIPC());

            fluent.withHostNetwork(instance.isHostNetwork());

            fluent.withHostPID(instance.isHostPID());

            fluent.withHostPorts(instance.getHostPorts());

            fluent.withPrivileged(instance.isPrivileged());

            fluent.withReadOnlyRootFilesystem(instance.isReadOnlyRootFilesystem());

            fluent.withRequiredDropCapabilities(instance.getRequiredDropCapabilities());

            fluent.withRunAsUser(instance.getRunAsUser());

            fluent.withSeLinux(instance.getSeLinux());

            fluent.withSupplementalGroups(instance.getSupplementalGroups());

            fluent.withVolumes(instance.getVolumes());

            this.validationEnabled = validationEnabled; 
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpec instance){
            this(instance,true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAllowPrivilegeEscalation(instance.isAllowPrivilegeEscalation());

            this.withAllowedCapabilities(instance.getAllowedCapabilities());

            this.withAllowedFlexVolumes(instance.getAllowedFlexVolumes());

            this.withAllowedHostPaths(instance.getAllowedHostPaths());

            this.withAllowedUnsafeSysctls(instance.getAllowedUnsafeSysctls());

            this.withDefaultAddCapabilities(instance.getDefaultAddCapabilities());

            this.withDefaultAllowPrivilegeEscalation(instance.isDefaultAllowPrivilegeEscalation());

            this.withForbiddenSysctls(instance.getForbiddenSysctls());

            this.withFsGroup(instance.getFsGroup());

            this.withHostIPC(instance.isHostIPC());

            this.withHostNetwork(instance.isHostNetwork());

            this.withHostPID(instance.isHostPID());

            this.withHostPorts(instance.getHostPorts());

            this.withPrivileged(instance.isPrivileged());

            this.withReadOnlyRootFilesystem(instance.isReadOnlyRootFilesystem());

            this.withRequiredDropCapabilities(instance.getRequiredDropCapabilities());

            this.withRunAsUser(instance.getRunAsUser());

            this.withSeLinux(instance.getSeLinux());

            this.withSupplementalGroups(instance.getSupplementalGroups());

            this.withVolumes(instance.getVolumes());

            this.validationEnabled = validationEnabled; 
    }

    public ExtensionsV1beta1PodSecurityPolicySpec build(){
            ExtensionsV1beta1PodSecurityPolicySpec buildable = new ExtensionsV1beta1PodSecurityPolicySpec();
            buildable.setAllowPrivilegeEscalation(fluent.isAllowPrivilegeEscalation());
            buildable.setAllowedCapabilities(fluent.getAllowedCapabilities());
            buildable.setAllowedFlexVolumes(fluent.getAllowedFlexVolumes());
            buildable.setAllowedHostPaths(fluent.getAllowedHostPaths());
            buildable.setAllowedUnsafeSysctls(fluent.getAllowedUnsafeSysctls());
            buildable.setDefaultAddCapabilities(fluent.getDefaultAddCapabilities());
            buildable.setDefaultAllowPrivilegeEscalation(fluent.isDefaultAllowPrivilegeEscalation());
            buildable.setForbiddenSysctls(fluent.getForbiddenSysctls());
            buildable.setFsGroup(fluent.getFsGroup());
            buildable.setHostIPC(fluent.isHostIPC());
            buildable.setHostNetwork(fluent.isHostNetwork());
            buildable.setHostPID(fluent.isHostPID());
            buildable.setHostPorts(fluent.getHostPorts());
            buildable.setPrivileged(fluent.isPrivileged());
            buildable.setReadOnlyRootFilesystem(fluent.isReadOnlyRootFilesystem());
            buildable.setRequiredDropCapabilities(fluent.getRequiredDropCapabilities());
            buildable.setRunAsUser(fluent.getRunAsUser());
            buildable.setSeLinux(fluent.getSeLinux());
            buildable.setSupplementalGroups(fluent.getSupplementalGroups());
            buildable.setVolumes(fluent.getVolumes());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1PodSecurityPolicySpecBuilder that = (ExtensionsV1beta1PodSecurityPolicySpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1PodSecurityPolicySpecBuilder.java <==
package io.kubernetes.client.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ExtensionsV1beta1PodSecurityPolicySpecBuilder extends ExtensionsV1beta1PodSecurityPolicySpecFluentImpl<ExtensionsV1beta1PodSecurityPolicySpecBuilder> implements VisitableBuilder<ExtensionsV1beta1PodSecurityPolicySpec,ExtensionsV1beta1PodSecurityPolicySpecBuilder>{

    ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent;
    Boolean validationEnabled;

    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(){
            this(true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(Boolean validationEnabled){
            this(new ExtensionsV1beta1PodSecurityPolicySpec(), validationEnabled);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent){
            this(fluent, true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ExtensionsV1beta1PodSecurityPolicySpec(), validationEnabled);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent,ExtensionsV1beta1PodSecurityPolicySpec instance){
            this(fluent, instance, true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpecFluent<?> fluent,ExtensionsV1beta1PodSecurityPolicySpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAllowPrivilegeEscalation(instance.isAllowPrivilegeEscalation());

            fluent.withAllowedCapabilities(instance.getAllowedCapabilities());

            fluent.withAllowedFlexVolumes(instance.getAllowedFlexVolumes());

            fluent.withAllowedHostPaths(instance.getAllowedHostPaths());

            fluent.withAllowedProcMountTypes(instance.getAllowedProcMountTypes());

            fluent.withAllowedUnsafeSysctls(instance.getAllowedUnsafeSysctls());

            fluent.withDefaultAddCapabilities(instance.getDefaultAddCapabilities());

            fluent.withDefaultAllowPrivilegeEscalation(instance.isDefaultAllowPrivilegeEscalation());

            fluent.withForbiddenSysctls(instance.getForbiddenSysctls());

            fluent.withFsGroup(instance.getFsGroup());

            fluent.withHostIPC(instance.isHostIPC());

            fluent.withHostNetwork(instance.isHostNetwork());

            fluent.withHostPID(instance.isHostPID());

            fluent.withHostPorts(instance.getHostPorts());

            fluent.withPrivileged(instance.isPrivileged());

            fluent.withReadOnlyRootFilesystem(instance.isReadOnlyRootFilesystem());

            fluent.withRequiredDropCapabilities(instance.getRequiredDropCapabilities());

            fluent.withRunAsUser(instance.getRunAsUser());

            fluent.withSeLinux(instance.getSeLinux());

            fluent.withSupplementalGroups(instance.getSupplementalGroups());

            fluent.withVolumes(instance.getVolumes());

            this.validationEnabled = validationEnabled; 
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpec instance){
            this(instance,true);
    }
    public ExtensionsV1beta1PodSecurityPolicySpecBuilder(ExtensionsV1beta1PodSecurityPolicySpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAllowPrivilegeEscalation(instance.isAllowPrivilegeEscalation());

            this.withAllowedCapabilities(instance.getAllowedCapabilities());

            this.withAllowedFlexVolumes(instance.getAllowedFlexVolumes());

            this.withAllowedHostPaths(instance.getAllowedHostPaths());

            this.withAllowedProcMountTypes(instance.getAllowedProcMountTypes());

            this.withAllowedUnsafeSysctls(instance.getAllowedUnsafeSysctls());

            this.withDefaultAddCapabilities(instance.getDefaultAddCapabilities());

            this.withDefaultAllowPrivilegeEscalation(instance.isDefaultAllowPrivilegeEscalation());

            this.withForbiddenSysctls(instance.getForbiddenSysctls());

            this.withFsGroup(instance.getFsGroup());

            this.withHostIPC(instance.isHostIPC());

            this.withHostNetwork(instance.isHostNetwork());

            this.withHostPID(instance.isHostPID());

            this.withHostPorts(instance.getHostPorts());

            this.withPrivileged(instance.isPrivileged());

            this.withReadOnlyRootFilesystem(instance.isReadOnlyRootFilesystem());

            this.withRequiredDropCapabilities(instance.getRequiredDropCapabilities());

            this.withRunAsUser(instance.getRunAsUser());

            this.withSeLinux(instance.getSeLinux());

            this.withSupplementalGroups(instance.getSupplementalGroups());

            this.withVolumes(instance.getVolumes());

            this.validationEnabled = validationEnabled; 
    }

    public ExtensionsV1beta1PodSecurityPolicySpec build(){
            ExtensionsV1beta1PodSecurityPolicySpec buildable = new ExtensionsV1beta1PodSecurityPolicySpec();
            buildable.setAllowPrivilegeEscalation(fluent.isAllowPrivilegeEscalation());
            buildable.setAllowedCapabilities(fluent.getAllowedCapabilities());
            buildable.setAllowedFlexVolumes(fluent.getAllowedFlexVolumes());
            buildable.setAllowedHostPaths(fluent.getAllowedHostPaths());
            buildable.setAllowedProcMountTypes(fluent.getAllowedProcMountTypes());
            buildable.setAllowedUnsafeSysctls(fluent.getAllowedUnsafeSysctls());
            buildable.setDefaultAddCapabilities(fluent.getDefaultAddCapabilities());
            buildable.setDefaultAllowPrivilegeEscalation(fluent.isDefaultAllowPrivilegeEscalation());
            buildable.setForbiddenSysctls(fluent.getForbiddenSysctls());
            buildable.setFsGroup(fluent.getFsGroup());
            buildable.setHostIPC(fluent.isHostIPC());
            buildable.setHostNetwork(fluent.isHostNetwork());
            buildable.setHostPID(fluent.isHostPID());
            buildable.setHostPorts(fluent.getHostPorts());
            buildable.setPrivileged(fluent.isPrivileged());
            buildable.setReadOnlyRootFilesystem(fluent.isReadOnlyRootFilesystem());
            buildable.setRequiredDropCapabilities(fluent.getRequiredDropCapabilities());
            buildable.setRunAsUser(fluent.getRunAsUser());
            buildable.setSeLinux(fluent.getSeLinux());
            buildable.setSupplementalGroups(fluent.getSupplementalGroups());
            buildable.setVolumes(fluent.getVolumes());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1PodSecurityPolicySpecBuilder that = (ExtensionsV1beta1PodSecurityPolicySpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
